SystemOrganization addCategory: #'DataLogger-Etoys-Graphing'!
SystemOrganization addCategory: #'DataLogger-Etoys-Spreadsheet'!
SystemOrganization addCategory: #'DataLogger-Etoys'!
SystemOrganization addCategory: #'DataLogger-Core-SensorTypes'!
SystemOrganization addCategory: #'DataLogger-Core'!

Morph subclass: #DLBasicGraphMorph
	instanceVariableNames: 'form pen cartesianBounds points sensor startTime dataColor isGraphing'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Etoys-Graphing'!

!DLBasicGraphMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 5/11/2011 14:38'!
on: aSensor
	^ (self basicNew setSensor: aSensor) initialize! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/6/2011 13:02'!
addPoint: aPoint
	points size = 1000 ifTrue: [points removeFirst].
	points add: aPoint ! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/6/2011 12:56'!
cartesianBounds
	^ cartesianBounds ! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/6/2011 11:41'!
cartesianBounds: aRectangle 
	cartesianBounds := aRectangle! !

!DLBasicGraphMorph methodsFor: 'calculations' stamp: 'Richo 5/11/2011 14:07'!
cartesianPointToPixel: aPoint in: graphBounds
	^ (self cartesianXToPixel: aPoint x in: graphBounds)
		@ (self cartesianYToPixel: aPoint y in: graphBounds)! !

!DLBasicGraphMorph methodsFor: 'calculations' stamp: 'Richo 5/11/2011 14:08'!
cartesianXToPixel: aNumber in: graphBounds
	^ (graphBounds left + (aNumber - cartesianBounds left * graphBounds width / cartesianBounds width)) rounded! !

!DLBasicGraphMorph methodsFor: 'calculations' stamp: 'Richo 5/11/2011 14:08'!
cartesianYToPixel: aNumber in: graphBounds
	^ (graphBounds bottom - (aNumber - cartesianBounds top * graphBounds height / cartesianBounds height)) rounded! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:19'!
dataColor
	^ dataColor! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:19'!
dataColor: aColor
	dataColor := aColor! !

!DLBasicGraphMorph methodsFor: 'drawing' stamp: 'Richo 5/11/2011 17:19'!
drawDataOn: aCanvas in: aRectangle
	| pointsToDraw |
	aCanvas
		frameRectangle: aRectangle color: Color gray muchLighter;
		line: aRectangle topLeft to: aRectangle bottomLeft color: Color gray;
		line: aRectangle bottomLeft - (0@1) to: aRectangle bottomRight - (0@1) color: Color gray.
	pointsToDraw := (points
				select: [:p | p x between: cartesianBounds left and: cartesianBounds right])
				asSortedCollection: [:a :b | a x < b x].
	pointsToDraw isEmpty
		ifTrue: [^ self].
	pointsToDraw
		withIndexDo: [:point :index |
			index = 1 ifFalse: [| from to |
				from := self cartesianPointToPixel: (pointsToDraw at: index - 1) in: aRectangle.
				to := self cartesianPointToPixel: point in: aRectangle.
				aCanvas line: from to: to color: dataColor
			]
		].! !

!DLBasicGraphMorph methodsFor: 'drawing' stamp: 'Richo 5/11/2011 19:18'!
drawLabelsOn: aCanvas
	"REMEMBER: It should return the graph bounds"
	| font yMaxLabelWidth yMinLabelWidth xMaxLabelWidth graphBounds allLabelsHeight xMinLabelWidth |
	font := TextStyle defaultFont.
	yMaxLabelWidth := font widthOfString: self yMaxLabel.
	yMinLabelWidth := font widthOfString: self yMinLabel.
	xMaxLabelWidth := font widthOfString: self xMaxLabel.
	xMinLabelWidth := font widthOfString: self xMinLabel.
	allLabelsHeight := font height.
	graphBounds := Rectangle 
		origin: bounds topLeft 
			+ ({yMaxLabelWidth. yMinLabelWidth. xMinLabelWidth / 2} max rounded @ (allLabelsHeight / 2) rounded) 
			+ (5 @ 0)
		corner: bounds bottomRight 
			- ((xMaxLabelWidth / 2) rounded @ allLabelsHeight)
			- (0 @ 5).
	aCanvas 
		drawString: self yMaxLabel
		at: graphBounds topLeft - (yMaxLabelWidth @ (allLabelsHeight / 2) rounded) - (5 @ 0);
		drawString: self yMinLabel
		at: graphBounds bottomLeft - (yMinLabelWidth @ (allLabelsHeight / 2) rounded) - (5 @ 0);
		drawString: self xMinLabel
		at: graphBounds bottomLeft - ((xMinLabelWidth / 2) rounded @ 0) + (0 @ 5);
		drawString: self xMaxLabel
		at: graphBounds bottomRight - ((xMaxLabelWidth / 2) rounded @ 0) + (0 @ 5).
	^ graphBounds! !

!DLBasicGraphMorph methodsFor: 'drawing' stamp: 'Richo 5/11/2011 17:16'!
drawOn: aCanvas 
	"aCanvas translucentImage: form at: bounds topLeft."
	| graphBounds |
	super drawOn: aCanvas.
	graphBounds := self drawLabelsOn: aCanvas.
	self drawDataOn: aCanvas in: graphBounds.
! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/6/2011 10:58'!
extent: newExtent
	form := Form extent: newExtent depth: 32.
	pen := Pen newOnForm: form.
	super extent: newExtent
! !

!DLBasicGraphMorph methodsFor: 'initialization' stamp: 'Richo 5/11/2011 19:14'!
initialize
	super initialize.
	self extent: 800@200; color: Color transparent.
	points := OrderedCollection new.
	cartesianBounds := (0 @ sensor type minVal corner: 2000 @ sensor type maxVal).
	startTime := Time millisecondClockValue.
	dataColor := Color black.
	isGraphing := false.! !

!DLBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/6/2011 11:57'!
move: aPoint 
	cartesianBounds := cartesianBounds translateBy: aPoint.
! !

!DLBasicGraphMorph methodsFor: 'as yet unclassified' stamp: 'Richo 5/11/2011 20:00'!
scrollTo: n
	| intervals selectedInterval |
	isGraphing ifTrue: [^ 1].
	intervals := OrderedCollection new.
	points first x to: points last x - 2000 by: 100 do: [:each |
		intervals add: {each. each + 2000}
		].
	selectedInterval := intervals at: 41 * n + 1.
	cartesianBounds := 
(selectedInterval first  @ sensor type minVal corner: selectedInterval second @ sensor type maxVal).
	self changed.
	n! !

!DLBasicGraphMorph methodsFor: 'private' stamp: 'Richo 5/11/2011 14:38'!
setSensor: aDLSensor
	sensor := aDLSensor ! !

!DLBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 19:10'!
startGraphing
	isGraphing := true.
	points := OrderedCollection new.
	cartesianBounds := (0 @ sensor type minVal corner: 2000 @ sensor type maxVal).
	startTime := Time millisecondClockValue.	
	self startStepping! !

!DLBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 17:51'!
step
	| now |
	isGraphing ifFalse: [^ self].
	now := Time millisecondClockValue - startTime.
	self cartesianBounds: (self cartesianBounds left @ sensor type minVal corner: self cartesianBounds right @ sensor type maxVal);
		 addPoint: now @ sensor value.
	now > self cartesianBounds right
		ifTrue: [self move: 100 @ 0].
	self changed! !

!DLBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/6/2011 10:57'!
stepTime
^ 1! !

!DLBasicGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 19:05'!
stopGraphing
	isGraphing := false.
	self stopStepping! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:10'!
xMaxLabel
	^ (self cartesianBounds right / 1000.0) printShowingDecimalPlaces: 2! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:10'!
xMinLabel
	^ (self cartesianBounds left / 1000.0) printShowingDecimalPlaces: 2! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:04'!
yMaxLabel
	^ sensor type maxVal asString! !

!DLBasicGraphMorph methodsFor: 'accessing' stamp: 'Richo 5/11/2011 17:04'!
yMinLabel
	^ sensor type minVal asString! !

Morph subclass: #DLGraphMorph
	instanceVariableNames: 'basicGraph slider'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Etoys-Graphing'!

!DLGraphMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 5/11/2011 17:43'!
on: aDLSensor
	^ self basicNew initializeWith: aDLSensor! !

!DLGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 17:48'!
button: label color: aColor
	^ SimpleButtonMorph new
		label: label;
		borderColor: aColor;
		color: (aColor lighter alpha: 0.5).! !

!DLGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 19:03'!
inARow: anArray
	^ (AlignmentMorph inARow: anArray) 
		borderWidth: 0;
		extent: 1@1;
		layoutInset: 0;
		cellInset: 5;
		vResizing: #shrinkWrap;
		hResizing: #spaceFill;
		wrapCentering: #center;
		cellPositioning: #center.! !

!DLGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 19:04'!
initialize
	super initialize.
	self layoutPolicy: TableLayout new;
		rubberBandCells: true;
		listDirection: #topToBottom;
		extent: 1@1;
		vResizing: #shrinkWrap;
		hResizing: #shrinkWrap;
		layoutInset: 5;
		cellInset: 10;
		borderWidth: 1;
		wrapCentering: #center;
		cellPositioning: #leftCenter;
		color: Color white;
		borderColor: Color gray! !

!DLGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 19:24'!
initializeWith: aDLSensor
	self initialize.
	self addMorphBack: (basicGraph := DLBasicGraphMorph on: aDLSensor);
		addMorphBack: (self inARow: {
			(self button: 'Iniciar' color: Color green)
				target: basicGraph; actionSelector: #startGraphing.
			(self button: 'Detener' color: Color red)
				target: basicGraph; actionSelector: #stopGraphing.
			(slider := self newSliderFrom: 0 to: 1) 
				setScaledValue: 1; 
				hResizing: #spaceFill; 
				actionSelector: #value:; 
				target: [:sliderValue | basicGraph scrollTo: sliderValue]
			})! !

!DLGraphMorph methodsFor: 'initialize-release' stamp: 'Richo 5/11/2011 19:25'!
newSliderFrom: minVal to: maxVal 
	^ SimpleSliderMorph new minVal: minVal;
		 maxVal: maxVal;
		 color: Color gray muchLighter;
		 sliderColor: Color blue muchDarker;
		 extent: 200 @ 15! !

!DLGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 20:02'!
step
	slider setScaledValue: 1! !

!DLGraphMorph methodsFor: 'stepping' stamp: 'Richo 5/11/2011 20:02'!
stepTime
	^ 200! !

Morph subclass: #DLSpreadsheetMorph
	instanceVariableNames: 'time sensor fileName spreadsheet state index'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Etoys-Spreadsheet'!

!DLSpreadsheetMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 13:41'!
new
	self shouldNotImplement! !

!DLSpreadsheetMorph class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 13:41'!
on: aDLSensor
	^ (self basicNew setSensor: aDLSensor) initialize! !

!DLSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/6/2011 15:51'!
button: label color: aColor
	^ SimpleButtonMorph new
		label: label;
		borderColor: aColor;
		color: (aColor lighter alpha: 0.5).! !

!DLSpreadsheetMorph methodsFor: 'initialize-release' stamp: 'Richo 5/4/2011 15:34'!
delete
	self stopStepping.
	super delete! !

!DLSpreadsheetMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 16:16'!
fileName
	^ fileName contents asString! !

!DLSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/4/2011 13:31'!
inAColumn: anArray
	^ (AlignmentMorph inAColumn: anArray)
		borderWidth: 0;
		extent: 1@1;
		layoutInset: 0;
		cellInset: 0;
		vResizing: #shrinkWrap;
		hResizing: #spaceFill;
		wrapCentering: #center;
		cellPositioning: #leftCenter.! !

!DLSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/4/2011 13:31'!
inARow: anArray
	^ (AlignmentMorph inARow: anArray) 
		borderWidth: 0;
		extent: 1@1;
		layoutInset: 0;
		cellInset: 0;
		vResizing: #shrinkWrap;
		hResizing: #spaceFill;
		wrapCentering: #center;
		cellPositioning: #center.! !

!DLSpreadsheetMorph methodsFor: 'initialize-release' stamp: 'Richo 5/6/2011 15:51'!
initialize
	super initialize.
	self layoutPolicy: TableLayout new;
		rubberBandCells: true;
		listDirection: #topToBottom;
		extent: 1@1;
		vResizing: #shrinkWrap;
		hResizing: #shrinkWrap;
		color: (Color r: 0.645 g: 0.71 b: 1.0);
		cornerStyle: #rounded;
		borderColor: #raised;
		layoutInset: 5;
		cellInset: 10.
	time := 0.
	state := #stopped.
	self initializeSubmorphs.! !

!DLSpreadsheetMorph methodsFor: 'initialize-release' stamp: 'Richo 5/4/2011 16:10'!
initializeSubmorphs
	self addMorphBack: ((self inAColumn: {
			self inARow: {
				self spacer.
				self text: sensor type xAxisLabel.
				self text: sensor type yAxisLabel.
				self spacer.
				}.
			spreadsheet := SpreadsheetMorph rows: self maxRows columns: 2})
			cellPositioning: #center).
	self addMorphBack: (self inAColumn: {
			'Nombre del archivo: ' asMorph.
			fileName := (self text: 'datos.csv')
				wrapFlag: false;
				borderWidth: 1;
				backgroundColor: (Color white alpha: 0.8);
				hResizing: #spaceFill.
			}).
	self addMorphBack: ((self inARow: {
			(self button: 'Iniciar' color: Color green)
				target: self; actionSelector: #startStepping.
			(self button: 'Pausar' color: Color yellow)
				target: self; actionSelector: #pauseStepping.
			(self button: 'Detener' color: Color red)
				target: self; actionSelector: #stopStepping.
			})
			cellInset: 5;
			cellPositioning: #leftCenter)
! !

!DLSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:50'!
isPaused
	^ state == #paused! !

!DLSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:15'!
isRunning
	^ state == #running! !

!DLSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:15'!
isStopped
	^ state == #stopped! !

!DLSpreadsheetMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 16:13'!
maxRows
	^ 20! !

!DLSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:16'!
pauseStepping
	state := #paused.
	super stopStepping! !

!DLSpreadsheetMorph methodsFor: 'printing' stamp: 'Richo 5/4/2011 15:16'!
print: aNumber
	^ (aNumber printShowingDecimalPlaces: 2) copyReplaceAll: '.' with: ','! !

!DLSpreadsheetMorph methodsFor: 'private' stamp: 'Richo 5/4/2011 13:50'!
setSensor: aDLSensor 
	sensor := aDLSensor ! !

!DLSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/4/2011 13:31'!
spacer
	^ AlignmentMorph newVariableTransparentSpacer.! !

!DLSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 16:16'!
startStepping
	self isStopped
		ifTrue: [
		time := Time millisecondClockValue.
		[(FileStream forceNewFileNamed: self fileName do: [:file |
			file nextPutAll: sensor type xAxisLabel;
				nextPut: $;;
				nextPutAll: sensor type yAxisLabel;
				cr])] on: Error do: [].
		index := 1.
		spreadsheet clearTable; setAppend].
	state := #running.
	super startStepping! !

!DLSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 16:16'!
step
	| |
	self isRunning ifFalse: [^ self].
	spreadsheet 
		cellValueAt: index @ 1 put: (self print: (Time millisecondClockValue - time) / 1000);
		cellValueAt: index @ 2 put: (self print: sensor value).
	index = self maxRows
		ifTrue: [
			spreadsheet 
				saveCSVFile: self fileName separator: $;;
				clearTable
			].
	index := (index \\ self maxRows) + 1! !

!DLSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 15:56'!
stepTime
	^ 1! !

!DLSpreadsheetMorph methodsFor: 'stepping' stamp: 'Richo 5/4/2011 16:17'!
stopStepping
	self isStopped ifTrue: [^ self].
	state := #stopped.
	spreadsheet
		saveCSVFile: self fileName
		separator: $;.
	super stopStepping! !

!DLSpreadsheetMorph methodsFor: 'building' stamp: 'Richo 5/4/2011 13:31'!
text: aString
	^ UserText new
		contents: aString;
		centered;
		autoFit: false;
		setExtentFromHalo: 100@23;
		layoutChanged! !

Morph subclass: #DataLoggerMorph
	instanceVariableNames: 'adquisidor portName sensorTypes'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Etoys'!

DataLoggerMorph class
	instanceVariableNames: 'form lastPortName'!

DataLoggerMorph class
	instanceVariableNames: 'form lastPortName'!

!DataLoggerMorph class methodsFor: 'viewer categories' stamp: 'Richo 4/25/2011 17:14'!
additionsToViewerCategories
^ #(
(#'adquisidor - conexin' (
#(command conectar 'Conecta este dispositivo' )
#(command desconectar 'Desconecta este dispositivo' )
#(slot estaConectado 'Muestra si el dispositivo est conectado' Boolean readOnly Player getEstaConectado Player unused )
#(slot #'nombre del puerto' 'Nombre del puerto en el que el dispositivo est conectado' AdquisidorPort readWrite Player getNombreDelPuerto Player setNombreDelPuerto: )
))


(#'adquisidor - sensores' (
#(slot #'sensor 0' 'Muestra el valor de este sensor' Number readOnly Player getSensor0 Player unused )
#(slot #'sensor 1' 'Muestra el valor de este sensor' Number readOnly Player getSensor1 Player unused )
#(slot #'sensor 2' 'Muestra el valor de este sensor' Number readOnly Player getSensor2 Player unused )
#(slot #'sensor 3' 'Muestra el valor de este sensor' Number readOnly Player getSensor3 Player unused )
#(slot #'sensor 4' 'Muestra el valor de este sensor' Number readOnly Player getSensor4 Player unused )
#(slot #'sensor 0 - tipo' 'Muestra el tipo de este sensor' AdquisidorSensorType readWrite Player getSensor0Tipo Player setSensor0Tipo: )
#(slot #'sensor 1 - tipo' 'Muestra el tipo de este sensor' AdquisidorSensorType readWrite Player getSensor1Tipo Player setSensor1Tipo: )
#(slot #'sensor 2 - tipo' 'Muestra el tipo de este sensor' AdquisidorSensorType readWrite Player getSensor2Tipo Player setSensor2Tipo: )
#(slot #'sensor 3 - tipo' 'Muestra el tipo de este sensor' AdquisidorSensorType readWrite Player getSensor3Tipo Player setSensor3Tipo: )
#(slot #'sensor 4 - tipo' 'Muestra el tipo de este sensor' AdquisidorSensorType readWrite Player getSensor4Tipo Player setSensor4Tipo: )

))
)! !

!DataLoggerMorph class methodsFor: 'viewer categories' stamp: 'Richo 5/4/2011 11:02'!
defaultNameStemForInstances
	^ 'Adquisidor'! !

!DataLoggerMorph class methodsFor: 'accessing' stamp: 'Richo 4/25/2011 17:08'!
descriptionForPartsBin
	"Answer a description for use in parts bins"
	^ self
		partName: 'Adquisidor' translatedNoop
		categories: {'Electronics' translatedNoop}
		documentation: 'Un objeto que te permite adquirir informacin del mundo fsico' translatedNoop! !

!DataLoggerMorph class methodsFor: 'form' stamp: 'Richo 4/25/2011 15:26'!
form
"
	form := nil.
"
^ form ifNil: [self initializeForm]! !

!DataLoggerMorph class methodsFor: 'form' stamp: 'Richo 4/25/2011 15:33'!
initializeForm
^ form := PEUtilities formFromEncodedPNG: 'iVBORw0KGgoAAAANSUhEUgAAAQcAAAEuCAYAAACDCNdZAAAABHNCSVQFBQUBSsjp7wAAmZdJ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'! !

!DataLoggerMorph class methodsFor: 'accessing' stamp: 'Richo 5/3/2011 15:07'!
lastPortName
^lastPortName! !

!DataLoggerMorph class methodsFor: 'accessing' stamp: 'Richo 4/25/2011 16:08'!
lastPortName: aSymbol
lastPortName := aSymbol! !

!DataLoggerMorph methodsFor: 'viewer category filter' stamp: 'Richo 4/25/2011 16:12'!
categoriesForViewer
	^self validCategories , #(scripting)! !

!DataLoggerMorph methodsFor: 'event handling' stamp: 'Richo 5/4/2011 11:34'!
chooseSensorTypeFor: sensor
	| newType typesToChoose |
	typesToChoose := sensorTypes keys asArray.
	newType := sensorTypes at: (UIManager default chooseFrom: typesToChoose values: typesToChoose title: 'Tipos:') ifAbsent: [^ self].
	sensor type: newType! !

!DataLoggerMorph methodsFor: 'connection' stamp: 'Richo 4/25/2011 16:17'!
connect
	[adquisidor connectOnPort: portName]
			on: Error
			do: [:err | self inform: err description]! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 4/25/2011 16:17'!
delete
self isConnected ifTrue: [self disconnect].
super delete.! !

!DataLoggerMorph methodsFor: 'connection' stamp: 'Richo 4/25/2011 16:17'!
disconnect
	adquisidor disconnect! !

!DataLoggerMorph methodsFor: 'drawing' stamp: 'Richo 4/25/2011 15:27'!
drawOn: aCanvas
aCanvas translucentImage: self class form at: self bounds topLeft! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 5/4/2011 11:11'!
initialize
	super initialize.
	self extent: self class form extent.
	adquisidor := DataLogger new.
	sensorTypes := Array new: 5 withAll: #raw.
	self initializePortName;
		initializeSensorTypes;
		initializeSubmorphs! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 5/4/2011 11:36'!
initializePortName
	| availablePorts list block |
	list := PESerialPortList.
	block := [(list availableSerialPorts , list availableUSBPorts) asSet asSortedCollection].
	availablePorts := block value.
	Vocabulary addStandardVocabulary: (PluggableListType new vocabularyName: #ArduinoPort;
			 block: [block value, #(#'other...' )]).
	(availablePorts includes: self class lastPortName)
		ifFalse: [self class lastPortName: availablePorts last].
	portName := self class lastPortName! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 5/4/2011 11:21'!
initializeSensorTypes
	sensorTypes := Dictionary new.
	DLSensorType withAllSubclassesDo: [:each |
		sensorTypes at: each sensorName asSymbol put: each].
	Vocabulary addStandardVocabulary: (SymbolListType new vocabularyName: #AdquisidorSensorType;
			 symbols: sensorTypes keys asArray)
	! !

!DataLoggerMorph methodsFor: 'initialize-release' stamp: 'Richo 5/3/2011 15:59'!
initializeSubmorphs
	#(103 74 45 16 -13)
		doWithIndex: [:y :index | | x morph |
			x := 101.
			morph := Morph new
						extent: 40@30;
						center: self center + (x@y);
						color: Color transparent;
						borderWidth: 2;
						borderColor: Color transparent;
						yourself.
			morph
				on: #mouseUp send: #mouseUp:event:morph: to: self withValue: index - 1;
				on: #mouseEnter send: #value:value: to: [:evt :m | m borderColor: Color red];
				on: #mouseLeave send: #value:value: to: [:evt :m | m borderColor: Color transparent].
			self addMorph: morph.
		]! !

!DataLoggerMorph methodsFor: 'connection' stamp: 'Richo 4/25/2011 16:17'!
isConnected
^adquisidor isConnected! !

!DataLoggerMorph methodsFor: 'event handling' stamp: 'Richo 5/6/2011 12:44'!
mouseUp: sensorIndex event: evt morph: aMorph 
	| choice sensor |
	aMorph borderColor: Color red.
	sensor := adquisidor sensors at: sensorIndex + 1.
	choice := UIManager default chooseFrom: #('tipo de sensor' 'dame grfico' 'dame planilla' ) title: ''.
	choice caseOf: {
		[1] -> [self chooseSensorTypeFor: sensor].
		[2] -> [self openGraphFor: sensor].
		[3] -> [self openSpreadsheetFor: sensor]}
		 otherwise: [].
	aMorph borderColor: Color transparent! !

!DataLoggerMorph methodsFor: 'viewer category filter' stamp: 'Richo 5/4/2011 11:01'!
newPlayerInstance
^ DataLoggerPlayer newUserInstance! !

!DataLoggerMorph methodsFor: 'event handling' stamp: 'Richo 5/11/2011 17:44'!
openGraphFor: sensor 
	(DLGraphMorph on: sensor) openInHand! !

!DataLoggerMorph methodsFor: 'event handling' stamp: 'Richo 5/4/2011 13:50'!
openSpreadsheetFor: sensor
	(DLSpreadsheetMorph on: sensor) openInHand! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 4/25/2011 16:13'!
portName
^ portName ! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 4/25/2011 16:13'!
portName: aSymbol 
	self isConnected
		ifTrue: [^ self].
	portName := aSymbol = #'other...'
				ifTrue: [(FillInTheBlank request: 'Port name:' translated) asSymbol]
				ifFalse: [aSymbol].
	self class lastPortName: portName! !

!DataLoggerMorph methodsFor: 'fileOut' stamp: 'Richo 4/25/2011 16:13'!
prepareToBeSaved
"When saving a project be sure to disconnect the board, otherwise we will have a lot of problems"
	super prepareToBeSaved.
	self isConnected ifTrue: [self disconnect]! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:06'!
sensor0
	^ adquisidor s0 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:20'!
sensor0Type
	^  adquisidor s0 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:19'!
sensor0Type: aSymbol
	^  adquisidor s0 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:06'!
sensor1
	^ adquisidor s1 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:20'!
sensor1Type
	^  adquisidor s1 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:19'!
sensor1Type: aSymbol
	^  adquisidor s1 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:08'!
sensor2
	^ adquisidor s2 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:20'!
sensor2Type
	^  adquisidor s2 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:19'!
sensor2Type: aSymbol
	^  adquisidor s2 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:08'!
sensor3
	^ adquisidor s3 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:20'!
sensor3Type
	^  adquisidor s3 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:20'!
sensor3Type: aSymbol
	^  adquisidor s3 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:08'!
sensor4
	^ adquisidor s4 value! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:20'!
sensor4Type
	^  adquisidor s4 type sensorName! !

!DataLoggerMorph methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:20'!
sensor4Type: aSymbol
	^  adquisidor s4 type: (sensorTypes at: aSymbol)! !

!DataLoggerMorph methodsFor: 'viewer category filter' stamp: 'Richo 4/25/2011 16:12'!
validCategories
"Returns valid categories for the Arduino object"
^(self class additionsToViewerCategories collect: [:each| each first])! !

Object subclass: #DLSensor
	instanceVariableNames: 'type values'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Core'!

!DLSensor methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:22'!
initialize
	super initialize.
	type := DLSensorType.
	values := OrderedCollection new
					add: -1;
					yourself! !

!DLSensor methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:21'!
type
	^ type! !

!DLSensor methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:22'!
type: aDLSensorType
	type := aDLSensorType 
	! !

!DLSensor methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:06'!
value
	^ values last! !

!DLSensor methodsFor: 'accessing' stamp: 'Richo 5/4/2011 11:06'!
value: aNumber
	| newValue |
	values add: (newValue := type scale: aNumber).
	self triggerEvent: #valueChanged with: newValue! !

Object subclass: #DLSensorType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Core-SensorTypes'!

DLSensorType subclass: #DLButtonType
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Core-SensorTypes'!

!DLButtonType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
interval
^ 0 to: 1! !

!DLButtonType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:19'!
scale: aNumber
	^ (aNumber / 1023) rounded! !

!DLButtonType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
sensorName
	^#botn! !

!DLSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
interval
^ 0 to: 1023! !

!DLSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
maxVal
^ self interval max! !

!DLSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
minVal
^ self interval min! !

!DLSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
scale: aNumber
	^ aNumber! !

!DLSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
sensorName
	^ #raw! !

!DLSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
xAxisLabel
	^ 'tiempo'! !

!DLSensorType class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:18'!
yAxisLabel
	^ 'valor'! !

Object subclass: #DataLogger
	instanceVariableNames: 'port steppingProcess sensors'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Core'!

!DataLogger methodsFor: 'connection' stamp: 'Richo 4/25/2011 15:03'!
connectOnPort: portName
	port := SerialPort new baudRate: 115200.
	port := port
				openPort: (('COM*' match: portName)
						ifTrue: [portName asInteger]
						ifFalse: [portName]).
	self isConnected
		ifTrue: [self startSteppingProcess]! !

!DataLogger methodsFor: 'connection' stamp: 'Richo 4/25/2011 15:43'!
disconnect
	self isConnected
		ifTrue: [self stopSteppingProcess.
			port close.
			port := nil.
			self initializeSensors]! !

!DataLogger methodsFor: 'initialize-release' stamp: 'Richo 4/25/2011 15:44'!
initialize
	super initialize.
	self initializeSensors! !

!DataLogger methodsFor: 'initialize-release' stamp: 'Richo 5/4/2011 11:24'!
initializeSensors
	sensors := (1 to: 5) collect: [:ign | DLSensor new]! !

!DataLogger methodsFor: 'connection' stamp: 'Richo 4/25/2011 15:02'!
isConnected
	^ port notNil! !

!DataLogger methodsFor: 'stepping' stamp: 'Richo 5/6/2011 12:49'!
processInput
"	| data |
	data := port readString.
	(data subStrings: String crlf)
		do: [:line | 
			((line beginsWith: 'S') and: [line includes: $;])
				ifTrue: [(sensors at: line second asString asNumber + 1)
						value: ((line upTo: $;) allButFirst: 3) asInteger]]"

	sensors do: [:s | s value: 1023 atRandom]! !

!DataLogger methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:42'!
s0
	^ sensors at: 1! !

!DataLogger methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:42'!
s1
	^ sensors at: 2! !

!DataLogger methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:43'!
s2
	^ sensors at: 3! !

!DataLogger methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:43'!
s3
	^ sensors at: 4! !

!DataLogger methodsFor: 'accessing' stamp: 'Richo 4/25/2011 15:43'!
s4
	^ sensors at: 5! !

!DataLogger methodsFor: 'accessing' stamp: 'Richo 5/4/2011 10:58'!
sensors
	^ sensors! !

!DataLogger methodsFor: 'stepping' stamp: 'Richo 4/25/2011 15:02'!
startSteppingProcess
	steppingProcess notNil
		ifTrue: [^ self].
	steppingProcess := [[self step.
			(Delay forMilliseconds: self stepTime) wait] repeat]
				forkNamed: self asString ! !

!DataLogger methodsFor: 'stepping' stamp: 'Richo 4/25/2011 17:10'!
step
	[self processInput]
		on: Error
		do: [:err | 
			Transcript show: self asString , ': ' , err description;
				 cr]! !

!DataLogger methodsFor: 'stepping' stamp: 'Richo 4/25/2011 16:23'!
stepTime
	^ 1! !

!DataLogger methodsFor: 'stepping' stamp: 'Richo 4/25/2011 15:34'!
stopSteppingProcess
	steppingProcess isNil
		ifTrue: [^ self].
	steppingProcess terminate.
	steppingProcess := nil! !

Player subclass: #DataLoggerPlayer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'DataLogger-Etoys'!

!DataLoggerPlayer class methodsFor: 'as yet unclassified' stamp: 'Richo 4/25/2011 16:44'!
isUniClass
	^ self ~~ self officialClass! !

!DataLoggerPlayer class methodsFor: 'as yet unclassified' stamp: 'Richo 5/4/2011 11:01'!
officialClass
	^ DataLoggerPlayer! !

!DataLoggerPlayer class methodsFor: 'as yet unclassified' stamp: 'Richo 4/25/2011 16:44'!
wantsChangeSetLogging
	"Log changes for Player itself, but not for automatically-created subclasses like Player1, Player2, but *do* log it for uniclasses that have been manually renamed."

	^ (self == self officialClass or:
		[(self name beginsWith: self officialClass asString) not]) or:
			[Preferences universalTiles]! !

!DataLoggerPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
conectar
^ self costume renderedMorph connect! !

!DataLoggerPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
desconectar
^ self costume renderedMorph disconnect! !

!DataLoggerPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
getEstaConectado
^ self costume renderedMorph isConnected! !

!DataLoggerPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
getNombreDelPuerto
 ^ self costume renderedMorph portName! !

!DataLoggerPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:14'!
getSensor0
	^ self costume renderedMorph sensor0! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:15'!
getSensor0Tipo
	^ self costume renderedMorph sensor0Type! !

!DataLoggerPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:14'!
getSensor1
	^ self costume renderedMorph sensor1! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:15'!
getSensor1Tipo
	^ self costume renderedMorph sensor1Type! !

!DataLoggerPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:14'!
getSensor2
	^ self costume renderedMorph sensor2! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:15'!
getSensor2Tipo
	^ self costume renderedMorph sensor2Type! !

!DataLoggerPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:15'!
getSensor3
	^ self costume renderedMorph sensor3! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:15'!
getSensor3Tipo
	^ self costume renderedMorph sensor3Type! !

!DataLoggerPlayer methodsFor: 'sensor values' stamp: 'Richo 4/25/2011 16:15'!
getSensor4
	^ self costume renderedMorph sensor4! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
getSensor4Tipo
	^ self costume renderedMorph sensor4Type! !

!DataLoggerPlayer methodsFor: 'connection' stamp: 'Richo 4/25/2011 17:15'!
setNombreDelPuerto: aSymbol 
	^ self costume renderedMorph
		portName: aSymbol! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor0Tipo: aSymbol
	self costume renderedMorph sensor0Type: aSymbol! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor1Tipo: aSymbol
	self costume renderedMorph sensor1Type: aSymbol! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor2Tipo: aSymbol
	self costume renderedMorph sensor2Type: aSymbol! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor3Tipo: aSymbol
	self costume renderedMorph sensor3Type: aSymbol! !

!DataLoggerPlayer methodsFor: 'sensor types' stamp: 'Richo 4/25/2011 17:16'!
setSensor4Tipo: aSymbol
	self costume renderedMorph sensor4Type: aSymbol! !
